@@ -5,5 +5,5 @@ from django.urls import re_path
 from core_oaipmh_provider_app import urls as core_oaipmh_provider_app_urls
 
 urlpatterns = [
-    re_path(r'^admin/', include(admin.site.urls)),
+    re_path(r"^admin/", include(admin.site.urls)),
 ] + core_oaipmh_provider_app_urls.urlpatterns
